package com.teamchat.client.sdk.demo;

import com.teamchat.client.sdk.Room;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.TextChatlet;
import com.teamchat.client.sdk.impl.TeamchatAPIImpl;

/**
 * Creates a new room between bot, roomMember1 and roomMember2
 * and posts a message in that room
 * 
 * Please remember to update the above 3 parameter viz.
 * authkey, roomMember1, roomMember2.
 */
public class CreateRoomDemo {
	public static final String authKey = "samplekey";
	public static final String roomMember1 = "user1@example.com";
	public static final String roomMember2 = "user2@example.com";
	public static final String roomMember3 = "user3@example.com";
	public static final String roomMember4 = "user4@example.com";
	
	public static void main(String[] args) throws Exception {
		TeamchatAPI api = TeamchatAPIImpl.fromFile("config.json")
				.setAuthenticationKey(authKey);
		Room r = api.context().create().welcome("Hi, Welcome to new Room.")
				.add(roomMember1)
				.add(roomMember2).add(roomMember3);

		api.perform(r.post(new TextChatlet("Hi there")));
		
		String roomid = r.getId();
		//you can save this roomid to send messages to the same
		//room rather than recreating a new room every time.
		
		api.perform(api.context().byId(roomid).post(
				new TextChatlet("Welcome back")));
		
		////you can add members to existing room.
		api.perform(api.context().byId(roomid).add(roomMember4));
		
		api.perform(api.context().p2p(roomMember1).post(new TextChatlet("This is a p2p Message")));
		
		
		//remove member from a room
		api.removeMember(roomMember2, r);
		//change admin
		api.changeAdminTo(roomMember3, r);
		//leave room
		api.leaveRoom(r);
		
		Room r2 = api.context().create().welcome("Hi, Welcome to new Room.")
				.add(roomMember1)
				.add(roomMember2).add(roomMember3).setName("Close");
		api.perform(r2.post(new TextChatlet("Hi there")));
		Thread.sleep(3000);
		
		api.closeRoom(r2);
		
	}
}
