package com.teamchat.client.sdk.demo;

import com.teamchat.client.annotations.OnComment;
import com.teamchat.client.annotations.OnKeyword;
import com.teamchat.client.sdk.TeamchatAPI;
import com.teamchat.client.sdk.chatlets.PrimaryChatlet;
import com.teamchat.client.sdk.impl.TeamchatAPIImpl;

/**
 * When someone sends a text message "create" in a room that contains
 * this bot, a new form is posted that asks to post a comment.
 * Futher when anyone posts comment to this form, the comment are
 * printed out to the console.
 * 
 * Please remember to update the authkey below.
 * 
 */
public class RecieveCommentDemo {

	public static final String authKey = "samplekey";
	
	@OnKeyword("create")
	public void onCreate(TeamchatAPI api) {
		api.perform(
				api.context().currentRoom().post(
						new PrimaryChatlet()
							.allowComments(true)
							.setQuestion("Please post a comment.")
							.setReplyScreen(api.objects().form()
									.addField(api.objects().label().name("hint").label("Please post a comment."))
									)
							.alias("persdet")
							));
	}
	
	@OnComment("persdet")
	public void onData(TeamchatAPI api) {
		String comment = api.context().currentComment().getComment();
		
		System.out.println("Received Comment");
		System.out.println("Comment:" + comment);

	}

	public static void main(String[] args) throws Exception {
		TeamchatAPIImpl.fromFile("config.json")
				.setAuthenticationKey(authKey)
				.startReceivingEvents(new RecieveCommentDemo());
	}
}
